/*********************************************************************
 *
 *                  DMA PMP transfer example file
 *
 *********************************************************************
 * FileName:        led_txfer.c
 * Dependencies:    plib.h
 *
 * Processor:       PIC32
 *
 * Complier:        MPLAB C32 v1 or higher
 *                  MPLAB IDE v8 or higher
 * Company:         Microchip Technology Inc.
 *
 * Software License Agreement
 *
 * The software supplied herewith by Microchip Technology Incorporated
 * (the Company) for its PIC Microcontroller is intended
 * and supplied to you, the Companys customer, for use solely and
 * exclusively on Microchip PIC Microcontroller products.
 * The software is owned by the Company and/or its supplier, and is
 * protected under applicable copyright laws. All rights are reserved.
 * Any use in violation of the foregoing restrictions may subject the
 * user to criminal sanctions under applicable laws, as well as to
 * civil liability for the breach of the terms and conditions of this
 * license.
 *
 * THIS SOFTWARE IS PROVIDED IN AN AS IS CONDITION. NO WARRANTIES,
 * WHETHER EXPRESS, IMPLIED OR STATUTORY, INCLUDING, BUT NOT LIMITED
 * TO, IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A
 * PARTICULAR PURPOSE APPLY TO THIS SOFTWARE. THE COMPANY SHALL NOT,
 * IN ANY CIRCUMSTANCES, BE LIABLE FOR SPECIAL, INCIDENTAL OR
 * CONSEQUENTIAL DAMAGES, FOR ANY REASON WHATSOEVER.
 *
 *
 * Author               Date        Comment
 *~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
 * $Id$
 *thk	11/15/10				adapted to LED Matrix full 16 bits
 thk 12/16/10 					adapted to EXp 32
 ********************************************************************/

/*********************************************************************
 *
 * This example blinks LEDs on the PIC32 starter board using a pattern stored in flash memory.
 * It uses the DMA controller to transfer data from flash to the I/O port controlling the LEDs.
 * The DMA transfer is initiated by a timer interrupt (we use the Timer23 in this example).
 * Once the pattern is completely transferred, the process is repeated.
 * modified by thk 11/15/10 for LED matrix
 ********************************************************************/
#include <plib.h>        /* PIC32 peripheral library */


//  Configuration Bit settings
//  System Clock = 80 MHz,  Peripherial Bus = 40 MHz
//  Primary Osc w/PLL (XT+,HS+,EC+PLL)
//  Input Divider    2x Divider
//  Multiplier      20x Multiplier
//  WDT disabled
//  Other options are don't care
//
#pragma config FNOSC = PRIPLL, POSCMOD = HS, FPLLIDIV = DIV_2, FPLLMUL = MUL_20, FPBDIV = DIV_2, FPLLODIV = DIV_1
#pragma config FWDTEN = OFF

#define	SYS_FREQ	80000000		// frequency we're running at





//#define	LED_BLINK_RATE	200			// LED blinking rate, in msec
#define	LED_BLINK_RATE	1			// LED blinking rate, in msec
// type in the bytes that define the pattern that will be output to the LED's
// no longer than DmaGetMaxTxferSize() bytes: this is the maximum DMA transfer size
static const unsigned int 	LED_pattern[]=
{
//	0x0f01,	0x0f02,	0x0f04,	0x0f08,	0x0f10,	0x0f20,	0x0f40,	//col1
//	0x0e81,	0x0e82,	0x0e84,	0x0e88,	0x0e90,	0x0ea0,	0x0ec0, // col2
//	0x0d81,	0x0d82,	0x0d84,	0x0d88,	0x0d90,	0x0da0,	0x0dc0, // col3
//	0x0b81,	0x0b82,	0x0b84,	0x0b88,	0x0b90,	0x0ba0,	0x0bc0, // col4
//	0x0781,	0x0782,	0x0784,	0x0788,	0x0790,	0x07a0,	0x07c0, // col5
//
	//letter small d
	0x0f40,	0x0f10,	0x0f08,0x0f20,0x0f08,					//1/2 lowercol1 
	0x0784, 0x0b84, 0x0d84, 0x0e84, 0x0f84,					//row 4
	0x07c0, 0x0bc0, 0x0dc0, 0x0ec0, 0x0fc0,
	0x0781,	0x0782,	0x0784,	0x0788,	0x0790,	0x07c0, // col5
	//letter small d
	0x0f40,	0x0f10,	0x0f08,0x0f20,0x0f08,					//1/2 lowercol1 
	0x0784, 0x0b84, 0x0d84, 0x0e84, 0x0f84,					//row 4
	0x07c0, 0x0bc0, 0x0dc0, 0x0ec0, 0x0fc0,
	0x0781,	0x0782,	0x0784,	0x0788,	0x0790,	0x07c0, // col5
		//letter small d
	0x0f40,	0x0f10,	0x0f08,0x0f20,0x0f08,					//1/2 lowercol1 
	0x0784, 0x0b84, 0x0d84, 0x0e84, 0x0f84,					//row 4
	0x07c0, 0x0bc0, 0x0dc0, 0x0ec0, 0x0fc0,
	0x0781,	0x0782,	0x0784,	0x0788,	0x0790,	0x07c0, // col5
		//letter small d
	0x0f40,	0x0f10,	0x0f08,0x0f20,0x0f08,					//1/2 lowercol1 
	0x0784, 0x0b84, 0x0d84, 0x0e84, 0x0f84,					//row 4
	0x07c0, 0x0bc0, 0x0dc0, 0x0ec0, 0x0fc0,
	0x0781,	0x0782,	0x0784,	0x0788,	0x0790,	0x07c0, // col5
		//letter small d
	0x0f40,	0x0f10,	0x0f08,0x0f20,0x0f08,					//1/2 lowercol1 
	0x0784, 0x0b84, 0x0d84, 0x0e84, 0x0f84,					//row 4
	0x07c0, 0x0bc0, 0x0dc0, 0x0ec0, 0x0fc0,
	0x0781,	0x0782,	0x0784,	0x0788,	0x0790,	0x07c0, // col5
		//letter small d
	0x0f40,	0x0f10,	0x0f08,0x0f20,0x0f08,					//1/2 lowercol1 
	0x0784, 0x0b84, 0x0d84, 0x0e84, 0x0f84,					//row 4
	0x07c0, 0x0bc0, 0x0dc0, 0x0ec0, 0x0fc0,
	0x0781,	0x0782,	0x0784,	0x0788,	0x0790,	0x07c0, // col5
		//letter small d
	0x0f40,	0x0f10,	0x0f08,0x0f20,0x0f08,					//1/2 lowercol1 
	0x0784, 0x0b84, 0x0d84, 0x0e84, 0x0f84,					//row 4
	0x07c0, 0x0bc0, 0x0dc0, 0x0ec0, 0x0fc0,
	0x0781,	0x0782,	0x0784,	0x0788,	0x0790,	0x07c0, // col5
		//letter small d
	0x0f40,	0x0f10,	0x0f08,0x0f20,0x0f08,					//1/2 lowercol1 
	0x0784, 0x0b84, 0x0d84, 0x0e84, 0x0f84,					//row 4
	0x07c0, 0x0bc0, 0x0dc0, 0x0ec0, 0x0fc0,
	0x0781,	0x0782,	0x0784,	0x0788,	0x0790,	0x07c0, // col5
		//letter small d
	0x0f40,	0x0f10,	0x0f08,0x0f20,0x0f08,					//1/2 lowercol1 
	0x0784, 0x0b84, 0x0d84, 0x0e84, 0x0f84,					//row 4
	0x07c0, 0x0bc0, 0x0dc0, 0x0ec0, 0x0fc0,
	0x0781,	0x0782,	0x0784,	0x0788,	0x0790,	0x07c0, // col5
		//letter small d
	0x0f40,	0x0f10,	0x0f08,0x0f20,0x0f08,					//1/2 lowercol1 
	0x0784, 0x0b84, 0x0d84, 0x0e84, 0x0f84,					//row 4
	0x07c0, 0x0bc0, 0x0dc0, 0x0ec0, 0x0fc0,
	0x0781,	0x0782,	0x0784,	0x0788,	0x0790,	0x07c0, // col5
		//letter small d
	0x0f40,	0x0f10,	0x0f08,0x0f20,0x0f08,					//1/2 lowercol1 
	0x0784, 0x0b84, 0x0d84, 0x0e84, 0x0f84,					//row 4
	0x07c0, 0x0bc0, 0x0dc0, 0x0ec0, 0x0fc0,
	0x0781,	0x0782,	0x0784,	0x0788,	0x0790,	0x07c0, // col5
		//letter small d
	0x0f40,	0x0f10,	0x0f08,0x0f20,0x0f08,					//1/2 lowercol1 
	0x0784, 0x0b84, 0x0d84, 0x0e84, 0x0f84,					//row 4
	0x07c0, 0x0bc0, 0x0dc0, 0x0ec0, 0x0fc0,
	0x0781,	0x0782,	0x0784,	0x0788,	0x0790,	0x07c0, // col5
		//letter small d
	0x0f40,	0x0f10,	0x0f08,0x0f20,0x0f08,					//1/2 lowercol1 
	0x0784, 0x0b84, 0x0d84, 0x0e84, 0x0f84,					//row 4
	0x07c0, 0x0bc0, 0x0dc0, 0x0ec0, 0x0fc0,
	0x0781,	0x0782,	0x0784,	0x0788,	0x0790,	0x07c0, // col5
		//letter small d
	0x0f40,	0x0f10,	0x0f08,0x0f20,0x0f08,					//1/2 lowercol1 
	0x0784, 0x0b84, 0x0d84, 0x0e84, 0x0f84,					//row 4
	0x07c0, 0x0bc0, 0x0dc0, 0x0ec0, 0x0fc0,
	0x0781,	0x0782,	0x0784,	0x0788,	0x0790,	0x07c0, // col5
		//letter small d
	0x0f40,	0x0f10,	0x0f08,0x0f20,0x0f08,					//1/2 lowercol1 
	0x0784, 0x0b84, 0x0d84, 0x0e84, 0x0f84,					//row 4
	0x07c0, 0x0bc0, 0x0dc0, 0x0ec0, 0x0fc0,
	0x0781,	0x0782,	0x0784,	0x0788,	0x0790,	0x07c0, // col5
		//letter small d
	0x0f40,	0x0f10,	0x0f08,0x0f20,0x0f08,					//1/2 lowercol1 
	0x0784, 0x0b84, 0x0d84, 0x0e84, 0x0f84,					//row 4
	0x07c0, 0x0bc0, 0x0dc0, 0x0ec0, 0x0fc0,
	0x0781,	0x0782,	0x0784,	0x0788,	0x0790,	0x07c0, // col5
		
	//letter small d
	0x0f40,	0x0f10,	0x0f08,0x0f20,0x0f08,					//1/2 lowercol1 
	0x0784, 0x0b84, 0x0d84, 0x0e84, 0x0f84,					//row 4
	0x07c0, 0x0bc0, 0x0dc0, 0x0ec0, 0x0fc0,
	0x0781,	0x0782,	0x0784,	0x0788,	0x0790,	0x07c0, // col5	
		//letter small d
	0x0f40,	0x0f10,	0x0f08,0x0f20,0x0f08,					//1/2 lowercol1 
	0x0784, 0x0b84, 0x0d84, 0x0e84, 0x0f84,					//row 4
	0x07c0, 0x0bc0, 0x0dc0, 0x0ec0, 0x0fc0,
	0x0781,	0x0782,	0x0784,	0x0788,	0x0790,	0x07c0, // col5	
		//letter small d
	0x0f40,	0x0f10,	0x0f08,0x0f20,0x0f08,					//1/2 lowercol1 
	0x0784, 0x0b84, 0x0d84, 0x0e84, 0x0f84,					//row 4
	0x07c0, 0x0bc0, 0x0dc0, 0x0ec0, 0x0fc0,
	0x0781,	0x0782,	0x0784,	0x0788,	0x0790,	0x07c0, // col5	
		//letter small d
	0x0f40,	0x0f10,	0x0f08,0x0f20,0x0f08,					//1/2 lowercol1 
	0x0784, 0x0b84, 0x0d84, 0x0e84, 0x0f84,					//row 4
	0x07c0, 0x0bc0, 0x0dc0, 0x0ec0, 0x0fc0,
	0x0781,	0x0782,	0x0784,	0x0788,	0x0790,	0x07c0, // col5	
		//letter small d
	0x0f40,	0x0f10,	0x0f08,0x0f20,0x0f08,					//1/2 lowercol1 
	0x0784, 0x0b84, 0x0d84, 0x0e84, 0x0f84,					//row 4
	0x07c0, 0x0bc0, 0x0dc0, 0x0ec0, 0x0fc0,
	0x0781,	0x0782,	0x0784,	0x0788,	0x0790,	0x07c0, // col5	
		//letter small d
	0x0f40,	0x0f10,	0x0f08,0x0f20,0x0f08,					//1/2 lowercol1 
	0x0784, 0x0b84, 0x0d84, 0x0e84, 0x0f84,					//row 4
	0x07c0, 0x0bc0, 0x0dc0, 0x0ec0, 0x0fc0,
	0x0781,	0x0782,	0x0784,	0x0788,	0x0790,	0x07c0, // col5	
		//letter small d
	0x0f40,	0x0f10,	0x0f08,0x0f20,0x0f08,					//1/2 lowercol1 
	0x0784, 0x0b84, 0x0d84, 0x0e84, 0x0f84,					//row 4
	0x07c0, 0x0bc0, 0x0dc0, 0x0ec0, 0x0fc0,
	0x0781,	0x0782,	0x0784,	0x0788,	0x0790,	0x07c0, // col5	
		//letter small d
	0x0f40,	0x0f10,	0x0f08,0x0f20,0x0f08,					//1/2 lowercol1 
	0x0784, 0x0b84, 0x0d84, 0x0e84, 0x0f84,					//row 4
	0x07c0, 0x0bc0, 0x0dc0, 0x0ec0, 0x0fc0,
	0x0781,	0x0782,	0x0784,	0x0788,	0x0790,	0x07c0, // col5	
		//letter small d
	0x0f40,	0x0f10,	0x0f08,0x0f20,0x0f08,					//1/2 lowercol1 
	0x0784, 0x0b84, 0x0d84, 0x0e84, 0x0f84,					//row 4
	0x07c0, 0x0bc0, 0x0dc0, 0x0ec0, 0x0fc0,
	0x0781,	0x0782,	0x0784,	0x0788,	0x0790,	0x07c0, // col5	
		//letter small d
	0x0f40,	0x0f10,	0x0f08,0x0f20,0x0f08,					//1/2 lowercol1 
	0x0784, 0x0b84, 0x0d84, 0x0e84, 0x0f84,					//row 4
	0x07c0, 0x0bc0, 0x0dc0, 0x0ec0, 0x0fc0,
	0x0781,	0x0782,	0x0784,	0x0788,	0x0790,	0x07c0, // col5	
		//letter small d
	0x0f40,	0x0f10,	0x0f08,0x0f20,0x0f08,					//1/2 lowercol1 
	0x0784, 0x0b84, 0x0d84, 0x0e84, 0x0f84,					//row 4
	0x07c0, 0x0bc0, 0x0dc0, 0x0ec0, 0x0fc0,
	0x0781,	0x0782,	0x0784,	0x0788,	0x0790,	0x07c0, // col5	
		//letter small d
	0x0f40,	0x0f10,	0x0f08,0x0f20,0x0f08,					//1/2 lowercol1 
	0x0784, 0x0b84, 0x0d84, 0x0e84, 0x0f84,					//row 4
	0x07c0, 0x0bc0, 0x0dc0, 0x0ec0, 0x0fc0,
	0x0781,	0x0782,	0x0784,	0x0788,	0x0790,	0x07c0, // col5	
		//letter small d
	0x0f40,	0x0f10,	0x0f08,0x0f20,0x0f08,					//1/2 lowercol1 
	0x0784, 0x0b84, 0x0d84, 0x0e84, 0x0f84,					//row 4
	0x07c0, 0x0bc0, 0x0dc0, 0x0ec0, 0x0fc0,
	0x0781,	0x0782,	0x0784,	0x0788,	0x0790,	0x07c0, // col5	
		//letter small d
	0x0f40,	0x0f10,	0x0f08,0x0f20,0x0f08,					//1/2 lowercol1 
	0x0784, 0x0b84, 0x0d84, 0x0e84, 0x0f84,					//row 4
	0x07c0, 0x0bc0, 0x0dc0, 0x0ec0, 0x0fc0,
	0x0781,	0x0782,	0x0784,	0x0788,	0x0790,	0x07c0, // col5	
		//letter small d
	0x0f40,	0x0f10,	0x0f08,0x0f20,0x0f08,					//1/2 lowercol1 
	0x0784, 0x0b84, 0x0d84, 0x0e84, 0x0f84,					//row 4
	0x07c0, 0x0bc0, 0x0dc0, 0x0ec0, 0x0fc0,
	0x0781,	0x0782,	0x0784,	0x0788,	0x0790,	0x07c0, // col5	
		
		//letter small d
	0x0f40,	0x0f10,	0x0f08,0x0f20,0x0f08,					//1/2 lowercol1 
	0x0784, 0x0b84, 0x0d84, 0x0e84, 0x0f84,					//row 4
	0x07c0, 0x0bc0, 0x0dc0, 0x0ec0, 0x0fc0,
	0x0781,	0x0782,	0x0784,	0x0788,	0x0790,	0x07c0, // col5	
	//letter small d
	0x0f40,	0x0f10,	0x0f08,0x0f20,0x0f08,					//1/2 lowercol1 
	0x0784, 0x0b84, 0x0d84, 0x0e84, 0x0f84,					//row 4
	0x07c0, 0x0bc0, 0x0dc0, 0x0ec0, 0x0fc0,
	0x0781,	0x0782,	0x0784,	0x0788,	0x0790,	0x07c0, // col5	
	//letter small d
	0x0f40,	0x0f10,	0x0f08,0x0f20,0x0f08,					//1/2 lowercol1 
	0x0784, 0x0b84, 0x0d84, 0x0e84, 0x0f84,					//row 4
	0x07c0, 0x0bc0, 0x0dc0, 0x0ec0, 0x0fc0,
	0x0781,	0x0782,	0x0784,	0x0788,	0x0790,	0x07c0, // col5	
	//letter small d
	0x0f40,	0x0f10,	0x0f08,0x0f20,0x0f08,					//1/2 lowercol1 
	0x0784, 0x0b84, 0x0d84, 0x0e84, 0x0f84,					//row 4
	0x07c0, 0x0bc0, 0x0dc0, 0x0ec0, 0x0fc0,
	0x0781,	0x0782,	0x0784,	0x0788,	0x0790,	0x07c0, // col5	
	//letter small d
	0x0f40,	0x0f10,	0x0f08,0x0f20,0x0f08,					//1/2 lowercol1 
	0x0784, 0x0b84, 0x0d84, 0x0e84, 0x0f84,					//row 4
	0x07c0, 0x0bc0, 0x0dc0, 0x0ec0, 0x0fc0,
	0x0781,	0x0782,	0x0784,	0x0788,	0x0790,	0x07c0, // col5	
	//letter small d
	0x0f40,	0x0f10,	0x0f08,0x0f20,0x0f08,					//1/2 lowercol1 
	0x0784, 0x0b84, 0x0d84, 0x0e84, 0x0f84,					//row 4
	0x07c0, 0x0bc0, 0x0dc0, 0x0ec0, 0x0fc0,
	0x0781,	0x0782,	0x0784,	0x0788,	0x0790,	0x07c0, // col5	
	//letter small d
	0x0f40,	0x0f10,	0x0f08,0x0f20,0x0f08,					//1/2 lowercol1 
	0x0784, 0x0b84, 0x0d84, 0x0e84, 0x0f84,					//row 4
	0x07c0, 0x0bc0, 0x0dc0, 0x0ec0, 0x0fc0,
	0x0781,	0x0782,	0x0784,	0x0788,	0x0790,	0x07c0, // col5	
	//letter small d
	0x0f40,	0x0f10,	0x0f08,0x0f20,0x0f08,					//1/2 lowercol1 
	0x0784, 0x0b84, 0x0d84, 0x0e84, 0x0f84,					//row 4
	0x07c0, 0x0bc0, 0x0dc0, 0x0ec0, 0x0fc0,
	0x0781,	0x0782,	0x0784,	0x0788,	0x0790,	0x07c0, // col5	
	//letter small d
	0x0f40,	0x0f10,	0x0f08,0x0f20,0x0f08,					//1/2 lowercol1 
	0x0784, 0x0b84, 0x0d84, 0x0e84, 0x0f84,					//row 4
	0x07c0, 0x0bc0, 0x0dc0, 0x0ec0, 0x0fc0,
	0x0781,	0x0782,	0x0784,	0x0788,	0x0790,	0x07c0, // col5	
	//letter small d
	0x0f40,	0x0f10,	0x0f08,0x0f20,0x0f08,					//1/2 lowercol1 
	0x0784, 0x0b84, 0x0d84, 0x0e84, 0x0f84,					//row 4
	0x07c0, 0x0bc0, 0x0dc0, 0x0ec0, 0x0fc0,
	0x0781,	0x0782,	0x0784,	0x0788,	0x0790,	0x07c0, // col5	
	//letter small d
	0x0f40,	0x0f10,	0x0f08,0x0f20,0x0f08,					//1/2 lowercol1 
	0x0784, 0x0b84, 0x0d84, 0x0e84, 0x0f84,					//row 4
	0x07c0, 0x0bc0, 0x0dc0, 0x0ec0, 0x0fc0,
	0x0781,	0x0782,	0x0784,	0x0788,	0x0790,	0x07c0, // col5	
	//letter small d
	0x0f40,	0x0f10,	0x0f08,0x0f20,0x0f08,					//1/2 lowercol1 
	0x0784, 0x0b84, 0x0d84, 0x0e84, 0x0f84,					//row 4
	0x07c0, 0x0bc0, 0x0dc0, 0x0ec0, 0x0fc0,
	0x0781,	0x0782,	0x0784,	0x0788,	0x0790,	0x07c0, // col5	
	//letter small d
	0x0f40,	0x0f10,	0x0f08,0x0f20,0x0f08,					//1/2 lowercol1 
	0x0784, 0x0b84, 0x0d84, 0x0e84, 0x0f84,					//row 4
	0x07c0, 0x0bc0, 0x0dc0, 0x0ec0, 0x0fc0,
	0x0781,	0x0782,	0x0784,	0x0788,	0x0790,	0x07c0, // col5	
	//letter small d
	0x0f40,	0x0f10,	0x0f08,0x0f20,0x0f08,					//1/2 lowercol1 
	0x0784, 0x0b84, 0x0d84, 0x0e84, 0x0f84,					//row 4
	0x07c0, 0x0bc0, 0x0dc0, 0x0ec0, 0x0fc0,
	0x0781,	0x0782,	0x0784,	0x0788,	0x0790,	0x07c0, // col5	

	//letter M
	0x0f01,	0x0f02,	0x0f04,	0x0f08,	0x0f10, 0x0f40,	//col1
	0x0781, 0x0b81, 0x0d81, 0x0e81, 0x0f82,					//row1 
	0x0d81,0x0d82,	0x0d84,	0x0d88,  // 1/2 uppercol3 
	0x0781,	0x0782,	0x0784,	0x0788,	0x0790,	0x07c0, // col5
	//letter M
	0x0f01,	0x0f02,	0x0f04,	0x0f08,	0x0f10, 0x0f40,	//col1
	0x0781, 0x0b81, 0x0d81, 0x0e81, 0x0f82,					//row1 
	0x0d81,0x0d82,	0x0d84,	0x0d88,  // 1/2 uppercol3 
	0x0781,	0x0782,	0x0784,	0x0788,	0x0790,	0x07c0, // col5
		//letter M
	0x0f01,	0x0f02,	0x0f04,	0x0f08,	0x0f10, 0x0f40,	//col1
	0x0781, 0x0b81, 0x0d81, 0x0e81, 0x0f82,					//row1 
	0x0d81,0x0d82,	0x0d84,	0x0d88,  // 1/2 uppercol3 
	0x0781,	0x0782,	0x0784,	0x0788,	0x0790,	0x07c0, // col5
		//letter M
	0x0f01,	0x0f02,	0x0f04,	0x0f08,	0x0f10, 0x0f40,	//col1
	0x0781, 0x0b81, 0x0d81, 0x0e81, 0x0f82,					//row1 
	0x0d81,0x0d82,	0x0d84,	0x0d88,  // 1/2 uppercol3 
	0x0781,	0x0782,	0x0784,	0x0788,	0x0790,	0x07c0, // col5
		//letter M
	0x0f01,	0x0f02,	0x0f04,	0x0f08,	0x0f10, 0x0f40,	//col1
	0x0781, 0x0b81, 0x0d81, 0x0e81, 0x0f82,					//row1 
	0x0d81,0x0d82,	0x0d84,	0x0d88,  // 1/2 uppercol3 
	0x0781,	0x0782,	0x0784,	0x0788,	0x0790,	0x07c0, // col5
		//letter M
	0x0f01,	0x0f02,	0x0f04,	0x0f08,	0x0f10, 0x0f40,	//col1
	0x0781, 0x0b81, 0x0d81, 0x0e81, 0x0f82,					//row1 
	0x0d81,0x0d82,	0x0d84,	0x0d88,  // 1/2 uppercol3 
	0x0781,	0x0782,	0x0784,	0x0788,	0x0790,	0x07c0, // col5
		//letter M
	0x0f01,	0x0f02,	0x0f04,	0x0f08,	0x0f10, 0x0f40,	//col1
	0x0781, 0x0b81, 0x0d81, 0x0e81, 0x0f82,					//row1 
	0x0d81,0x0d82,	0x0d84,	0x0d88,  // 1/2 uppercol3 
	0x0781,	0x0782,	0x0784,	0x0788,	0x0790,	0x07c0, // col5
		//letter M
	0x0f01,	0x0f02,	0x0f04,	0x0f08,	0x0f10, 0x0f40,	//col1
	0x0781, 0x0b81, 0x0d81, 0x0e81, 0x0f82,					//row1 
	0x0d81,0x0d82,	0x0d84,	0x0d88,  // 1/2 uppercol3 
	0x0781,	0x0782,	0x0784,	0x0788,	0x0790,	0x07c0, // col5
		//letter M
	0x0f01,	0x0f02,	0x0f04,	0x0f08,	0x0f10, 0x0f40,	//col1
	0x0781, 0x0b81, 0x0d81, 0x0e81, 0x0f82,					//row1 
	0x0d81,0x0d82,	0x0d84,	0x0d88,  // 1/2 uppercol3 
	0x0781,	0x0782,	0x0784,	0x0788,	0x0790,	0x07c0, // col5
		//letter M
	0x0f01,	0x0f02,	0x0f04,	0x0f08,	0x0f10, 0x0f40,	//col1
	0x0781, 0x0b81, 0x0d81, 0x0e81, 0x0f82,					//row1 
	0x0d81,0x0d82,	0x0d84,	0x0d88,  // 1/2 uppercol3 
	0x0781,	0x0782,	0x0784,	0x0788,	0x0790,	0x07c0, // col5
		//letter M
	0x0f01,	0x0f02,	0x0f04,	0x0f08,	0x0f10, 0x0f40,	//col1
	0x0781, 0x0b81, 0x0d81, 0x0e81, 0x0f82,					//row1 
	0x0d81,0x0d82,	0x0d84,	0x0d88,  // 1/2 uppercol3 
	0x0781,	0x0782,	0x0784,	0x0788,	0x0790,	0x07c0, // col5
		//letter M
	0x0f01,	0x0f02,	0x0f04,	0x0f08,	0x0f10, 0x0f40,	//col1
	0x0781, 0x0b81, 0x0d81, 0x0e81, 0x0f82,					//row1 
	0x0d81,0x0d82,	0x0d84,	0x0d88,  // 1/2 uppercol3 
	0x0781,	0x0782,	0x0784,	0x0788,	0x0790,	0x07c0, // col5
		//letter M
	0x0f01,	0x0f02,	0x0f04,	0x0f08,	0x0f10, 0x0f40,	//col1
	0x0781, 0x0b81, 0x0d81, 0x0e81, 0x0f82,					//row1 
	0x0d81,0x0d82,	0x0d84,	0x0d88,  // 1/2 uppercol3 
	0x0781,	0x0782,	0x0784,	0x0788,	0x0790,	0x07c0, // col5
		//letter M
	0x0f01,	0x0f02,	0x0f04,	0x0f08,	0x0f10, 0x0f40,	//col1
	0x0781, 0x0b81, 0x0d81, 0x0e81, 0x0f82,					//row1 
	0x0d81,0x0d82,	0x0d84,	0x0d88,  // 1/2 uppercol3 
	0x0781,	0x0782,	0x0784,	0x0788,	0x0790,	0x07c0, // col5
		//letter M
	0x0f01,	0x0f02,	0x0f04,	0x0f08,	0x0f10, 0x0f40,	//col1
	0x0781, 0x0b81, 0x0d81, 0x0e81, 0x0f82,					//row1 
	0x0d81,0x0d82,	0x0d84,	0x0d88,  // 1/2 uppercol3 
	0x0781,	0x0782,	0x0784,	0x0788,	0x0790,	0x07c0, // col5
		//letter M
	0x0f01,	0x0f02,	0x0f04,	0x0f08,	0x0f10, 0x0f40,	//col1
	0x0781, 0x0b81, 0x0d81, 0x0e81, 0x0f82,					//row1 
	0x0d81,0x0d82,	0x0d84,	0x0d88,  // 1/2 uppercol3 
	0x0781,	0x0782,	0x0784,	0x0788,	0x0790,	0x07c0, // col5
		
		//letter M
	0x0f01,	0x0f02,	0x0f04,	0x0f08,	0x0f10, 0x0f40,	//col1
	0x0781, 0x0b81, 0x0d81, 0x0e81, 0x0f82,					//row1 
	0x0d81,0x0d82,	0x0d84,	0x0d88,  // 1/2 uppercol3 
	0x0781,	0x0782,	0x0784,	0x0788,	0x0790,	0x07c0, // col5	
		//letter M
	0x0f01,	0x0f02,	0x0f04,	0x0f08,	0x0f10, 0x0f40,	//col1
	0x0781, 0x0b81, 0x0d81, 0x0e81, 0x0f82,					//row1 
	0x0d81,0x0d82,	0x0d84,	0x0d88,  // 1/2 uppercol3 
	0x0781,	0x0782,	0x0784,	0x0788,	0x0790,	0x07c0, // col5	
		//letter M
	0x0f01,	0x0f02,	0x0f04,	0x0f08,	0x0f10, 0x0f40,	//col1
	0x0781, 0x0b81, 0x0d81, 0x0e81, 0x0f82,					//row1 
	0x0d81,0x0d82,	0x0d84,	0x0d88,  // 1/2 uppercol3 
	0x0781,	0x0782,	0x0784,	0x0788,	0x0790,	0x07c0, // col5	
		//letter M
	0x0f01,	0x0f02,	0x0f04,	0x0f08,	0x0f10, 0x0f40,	//col1
	0x0781, 0x0b81, 0x0d81, 0x0e81, 0x0f82,					//row1 
	0x0d81,0x0d82,	0x0d84,	0x0d88,  // 1/2 uppercol3 
	0x0781,	0x0782,	0x0784,	0x0788,	0x0790,	0x07c0, // col5	
		//letter M
	0x0f01,	0x0f02,	0x0f04,	0x0f08,	0x0f10, 0x0f40,	//col1
	0x0781, 0x0b81, 0x0d81, 0x0e81, 0x0f82,					//row1 
	0x0d81,0x0d82,	0x0d84,	0x0d88,  // 1/2 uppercol3 
	0x0781,	0x0782,	0x0784,	0x0788,	0x0790,	0x07c0, // col5	
		//letter M
	0x0f01,	0x0f02,	0x0f04,	0x0f08,	0x0f10, 0x0f40,	//col1
	0x0781, 0x0b81, 0x0d81, 0x0e81, 0x0f82,					//row1 
	0x0d81,0x0d82,	0x0d84,	0x0d88,  // 1/2 uppercol3 
	0x0781,	0x0782,	0x0784,	0x0788,	0x0790,	0x07c0, // col5	
		//letter M
	0x0f01,	0x0f02,	0x0f04,	0x0f08,	0x0f10, 0x0f40,	//col1
	0x0781, 0x0b81, 0x0d81, 0x0e81, 0x0f82,					//row1 
	0x0d81,0x0d82,	0x0d84,	0x0d88,  // 1/2 uppercol3 
	0x0781,	0x0782,	0x0784,	0x0788,	0x0790,	0x07c0, // col5	
		//letter M
	0x0f01,	0x0f02,	0x0f04,	0x0f08,	0x0f10, 0x0f40,	//col1
	0x0781, 0x0b81, 0x0d81, 0x0e81, 0x0f82,					//row1 
	0x0d81,0x0d82,	0x0d84,	0x0d88,  // 1/2 uppercol3 
	0x0781,	0x0782,	0x0784,	0x0788,	0x0790,	0x07c0, // col5	
		//letter M
	0x0f01,	0x0f02,	0x0f04,	0x0f08,	0x0f10, 0x0f40,	//col1
	0x0781, 0x0b81, 0x0d81, 0x0e81, 0x0f82,					//row1 
	0x0d81,0x0d82,	0x0d84,	0x0d88,  // 1/2 uppercol3 
	0x0781,	0x0782,	0x0784,	0x0788,	0x0790,	0x07c0, // col5	
		//letter M
	0x0f01,	0x0f02,	0x0f04,	0x0f08,	0x0f10, 0x0f40,	//col1
	0x0781, 0x0b81, 0x0d81, 0x0e81, 0x0f82,					//row1 
	0x0d81,0x0d82,	0x0d84,	0x0d88,  // 1/2 uppercol3 
	0x0781,	0x0782,	0x0784,	0x0788,	0x0790,	0x07c0, // col5	
		//letter M
	0x0f01,	0x0f02,	0x0f04,	0x0f08,	0x0f10, 0x0f40,	//col1
	0x0781, 0x0b81, 0x0d81, 0x0e81, 0x0f82,					//row1 
	0x0d81,0x0d82,	0x0d84,	0x0d88,  // 1/2 uppercol3 
	0x0781,	0x0782,	0x0784,	0x0788,	0x0790,	0x07c0, // col5	
		//letter M
	0x0f01,	0x0f02,	0x0f04,	0x0f08,	0x0f10, 0x0f40,	//col1
	0x0781, 0x0b81, 0x0d81, 0x0e81, 0x0f82,					//row1 
	0x0d81,0x0d82,	0x0d84,	0x0d88,  // 1/2 uppercol3 
	0x0781,	0x0782,	0x0784,	0x0788,	0x0790,	0x07c0, // col5	
		//letter M
	0x0f01,	0x0f02,	0x0f04,	0x0f08,	0x0f10, 0x0f40,	//col1
	0x0781, 0x0b81, 0x0d81, 0x0e81, 0x0f82,					//row1 
	0x0d81,0x0d82,	0x0d84,	0x0d88,  // 1/2 uppercol3 
	0x0781,	0x0782,	0x0784,	0x0788,	0x0790,	0x07c0, // col5	
		//letter M
	0x0f01,	0x0f02,	0x0f04,	0x0f08,	0x0f10, 0x0f40,	//col1
	0x0781, 0x0b81, 0x0d81, 0x0e81, 0x0f82,					//row1 
	0x0d81,0x0d82,	0x0d84,	0x0d88,  // 1/2 uppercol3 
	0x0781,	0x0782,	0x0784,	0x0788,	0x0790,	0x07c0, // col5	
		//letter M
	0x0f01,	0x0f02,	0x0f04,	0x0f08,	0x0f10, 0x0f40,	//col1
	0x0781, 0x0b81, 0x0d81, 0x0e81, 0x0f82,					//row1 
	0x0d81,0x0d82,	0x0d84,	0x0d88,  // 1/2 uppercol3 
	0x0781,	0x0782,	0x0784,	0x0788,	0x0790,	0x07c0, // col5		
	//letter M
	0x0f01,	0x0f02,	0x0f04,	0x0f08,	0x0f10, 0x0f40,	//col1
	0x0781, 0x0b81, 0x0d81, 0x0e81, 0x0f82,					//row1 
	0x0d81,0x0d82,	0x0d84,	0x0d88,  // 1/2 uppercol3 
	0x0781,	0x0782,	0x0784,	0x0788,	0x0790,	0x07c0, // col5	
	//letter M
	0x0f01,	0x0f02,	0x0f04,	0x0f08,	0x0f10, 0x0f40,	//col1
	0x0781, 0x0b81, 0x0d81, 0x0e81, 0x0f82,					//row1 
	0x0d81,0x0d82,	0x0d84,	0x0d88,  // 1/2 uppercol3 
	0x0781,	0x0782,	0x0784,	0x0788,	0x0790,	0x07c0, // col5	
	//letter M
	0x0f01,	0x0f02,	0x0f04,	0x0f08,	0x0f10, 0x0f40,	//col1
	0x0781, 0x0b81, 0x0d81, 0x0e81, 0x0f82,					//row1 
	0x0d81,0x0d82,	0x0d84,	0x0d88,  // 1/2 uppercol3 
	0x0781,	0x0782,	0x0784,	0x0788,	0x0790,	0x07c0, // col5	
	//letter M
	0x0f01,	0x0f02,	0x0f04,	0x0f08,	0x0f10, 0x0f40,	//col1
	0x0781, 0x0b81, 0x0d81, 0x0e81, 0x0f82,					//row1 
	0x0d81,0x0d82,	0x0d84,	0x0d88,  // 1/2 uppercol3 
	0x0781,	0x0782,	0x0784,	0x0788,	0x0790,	0x07c0, // col5	
	//letter M
	0x0f01,	0x0f02,	0x0f04,	0x0f08,	0x0f10, 0x0f40,	//col1
	0x0781, 0x0b81, 0x0d81, 0x0e81, 0x0f82,					//row1 
	0x0d81,0x0d82,	0x0d84,	0x0d88,  // 1/2 uppercol3 
	0x0781,	0x0782,	0x0784,	0x0788,	0x0790,	0x07c0, // col5	
	//letter M
	0x0f01,	0x0f02,	0x0f04,	0x0f08,	0x0f10, 0x0f40,	//col1
	0x0781, 0x0b81, 0x0d81, 0x0e81, 0x0f82,					//row1 
	0x0d81,0x0d82,	0x0d84,	0x0d88,  // 1/2 uppercol3 
	0x0781,	0x0782,	0x0784,	0x0788,	0x0790,	0x07c0, // col5	
	//letter M
	0x0f01,	0x0f02,	0x0f04,	0x0f08,	0x0f10, 0x0f40,	//col1
	0x0781, 0x0b81, 0x0d81, 0x0e81, 0x0f82,					//row1 
	0x0d81,0x0d82,	0x0d84,	0x0d88,  // 1/2 uppercol3 
	0x0781,	0x0782,	0x0784,	0x0788,	0x0790,	0x07c0, // col5	
	//letter M
	0x0f01,	0x0f02,	0x0f04,	0x0f08,	0x0f10, 0x0f40,	//col1
	0x0781, 0x0b81, 0x0d81, 0x0e81, 0x0f82,					//row1 
	0x0d81,0x0d82,	0x0d84,	0x0d88,  // 1/2 uppercol3 
	0x0781,	0x0782,	0x0784,	0x0788,	0x0790,	0x07c0, // col5	
	//letter M
	0x0f01,	0x0f02,	0x0f04,	0x0f08,	0x0f10, 0x0f40,	//col1
	0x0781, 0x0b81, 0x0d81, 0x0e81, 0x0f82,					//row1 
	0x0d81,0x0d82,	0x0d84,	0x0d88,  // 1/2 uppercol3 
	0x0781,	0x0782,	0x0784,	0x0788,	0x0790,	0x07c0, // col5	
	//letter M
	0x0f01,	0x0f02,	0x0f04,	0x0f08,	0x0f10, 0x0f40,	//col1
	0x0781, 0x0b81, 0x0d81, 0x0e81, 0x0f82,					//row1 
	0x0d81,0x0d82,	0x0d84,	0x0d88,  // 1/2 uppercol3 
	0x0781,	0x0782,	0x0784,	0x0788,	0x0790,	0x07c0, // col5	
	//letter M
	0x0f01,	0x0f02,	0x0f04,	0x0f08,	0x0f10, 0x0f40,	//col1
	0x0781, 0x0b81, 0x0d81, 0x0e81, 0x0f82,					//row1 
	0x0d81,0x0d82,	0x0d84,	0x0d88,  // 1/2 uppercol3 
	0x0781,	0x0782,	0x0784,	0x0788,	0x0790,	0x07c0, // col5	
	//letter M
	0x0f01,	0x0f02,	0x0f04,	0x0f08,	0x0f10, 0x0f40,	//col1
	0x0781, 0x0b81, 0x0d81, 0x0e81, 0x0f82,					//row1 
	0x0d81,0x0d82,	0x0d84,	0x0d88,  // 1/2 uppercol3 
	0x0781,	0x0782,	0x0784,	0x0788,	0x0790,	0x07c0, // col5	
	//letter M
	0x0f01,	0x0f02,	0x0f04,	0x0f08,	0x0f10, 0x0f40,	//col1
	0x0781, 0x0b81, 0x0d81, 0x0e81, 0x0f82,					//row1 
	0x0d81,0x0d82,	0x0d84,	0x0d88,  // 1/2 uppercol3 
	0x0781,	0x0782,	0x0784,	0x0788,	0x0790,	0x07c0, // col5	
	//letter M
	0x0f01,	0x0f02,	0x0f04,	0x0f08,	0x0f10, 0x0f40,	//col1
	0x0781, 0x0b81, 0x0d81, 0x0e81, 0x0f82,					//row1 
	0x0d81,0x0d82,	0x0d84,	0x0d88,  // 1/2 uppercol3 
	0x0781,	0x0782,	0x0784,	0x0788,	0x0790,	0x07c0, // col5	
	//letter M
	0x0f01,	0x0f02,	0x0f04,	0x0f08,	0x0f10, 0x0f40,	//col1
	0x0781, 0x0b81, 0x0d81, 0x0e81, 0x0f82,					//row1 
	0x0d81,0x0d82,	0x0d84,	0x0d88,  // 1/2 uppercol3 
	0x0781,	0x0782,	0x0784,	0x0788,	0x0790,	0x07c0, // col5	

//letter A
	0x0f01,	0x0f02,	0x0f04,	0x0f08,	0x0f10,0x0f40,	//col1
	0x0781, 0x0b81, 0x0d81, 0x0e81, 0x0f82,					//row1 
	0x0784, 0x0b84, 0x0d84, 0x0e84, 0x0f84,					//row 5
	0x0781,	0x0782,	0x0784,	0x0788,	0x0790,	0x07c0, // col5
//letter A
	0x0f01,	0x0f02,	0x0f04,	0x0f08,	0x0f10,0x0f40,	//col1
	0x0781, 0x0b81, 0x0d81, 0x0e81, 0x0f82,					//row1 
	0x0784, 0x0b84, 0x0d84, 0x0e84, 0x0f84,					//row 5
	0x0781,	0x0782,	0x0784,	0x0788,	0x0790,	0x07c0, // col5
	//letter A
	0x0f01,	0x0f02,	0x0f04,	0x0f08,	0x0f10,0x0f40,	//col1
	0x0781, 0x0b81, 0x0d81, 0x0e81, 0x0f82,					//row1 
	0x0784, 0x0b84, 0x0d84, 0x0e84, 0x0f84,					//row 5
	0x0781,	0x0782,	0x0784,	0x0788,	0x0790,	0x07c0, // col5
	//letter A
	0x0f01,	0x0f02,	0x0f04,	0x0f08,	0x0f10,0x0f40,	//col1
	0x0781, 0x0b81, 0x0d81, 0x0e81, 0x0f82,					//row1 
	0x0784, 0x0b84, 0x0d84, 0x0e84, 0x0f84,					//row 5
	0x0781,	0x0782,	0x0784,	0x0788,	0x0790,	0x07c0, // col5
	//letter A
	0x0f01,	0x0f02,	0x0f04,	0x0f08,	0x0f10,0x0f40,	//col1
	0x0781, 0x0b81, 0x0d81, 0x0e81, 0x0f82,					//row1 
	0x0784, 0x0b84, 0x0d84, 0x0e84, 0x0f84,					//row 5
	0x0781,	0x0782,	0x0784,	0x0788,	0x0790,	0x07c0, // col5
	//letter A
	0x0f01,	0x0f02,	0x0f04,	0x0f08,	0x0f10,0x0f40,	//col1
	0x0781, 0x0b81, 0x0d81, 0x0e81, 0x0f82,					//row1 
	0x0784, 0x0b84, 0x0d84, 0x0e84, 0x0f84,					//row 5
	0x0781,	0x0782,	0x0784,	0x0788,	0x0790,	0x07c0, // col5
	//letter A
	0x0f01,	0x0f02,	0x0f04,	0x0f08,	0x0f10,0x0f40,	//col1
	0x0781, 0x0b81, 0x0d81, 0x0e81, 0x0f82,					//row1 
	0x0784, 0x0b84, 0x0d84, 0x0e84, 0x0f84,					//row 5
	0x0781,	0x0782,	0x0784,	0x0788,	0x0790,	0x07c0, // col5
	//letter A
	0x0f01,	0x0f02,	0x0f04,	0x0f08,	0x0f10,0x0f40,	//col1
	0x0781, 0x0b81, 0x0d81, 0x0e81, 0x0f82,					//row1 
	0x0784, 0x0b84, 0x0d84, 0x0e84, 0x0f84,					//row 5
	0x0781,	0x0782,	0x0784,	0x0788,	0x0790,	0x07c0, // col5
	//letter A
	0x0f01,	0x0f02,	0x0f04,	0x0f08,	0x0f10,0x0f40,	//col1
	0x0781, 0x0b81, 0x0d81, 0x0e81, 0x0f82,					//row1 
	0x0784, 0x0b84, 0x0d84, 0x0e84, 0x0f84,					//row 5
	0x0781,	0x0782,	0x0784,	0x0788,	0x0790,	0x07c0, // col5
	//letter A
	0x0f01,	0x0f02,	0x0f04,	0x0f08,	0x0f10,0x0f40,	//col1
	0x0781, 0x0b81, 0x0d81, 0x0e81, 0x0f82,					//row1 
	0x0784, 0x0b84, 0x0d84, 0x0e84, 0x0f84,					//row 5
	0x0781,	0x0782,	0x0784,	0x0788,	0x0790,	0x07c0, // col5
	//letter A
	0x0f01,	0x0f02,	0x0f04,	0x0f08,	0x0f10,0x0f40,	//col1
	0x0781, 0x0b81, 0x0d81, 0x0e81, 0x0f82,					//row1 
	0x0784, 0x0b84, 0x0d84, 0x0e84, 0x0f84,					//row 5
	0x0781,	0x0782,	0x0784,	0x0788,	0x0790,	0x07c0, // col5
	//letter A
	0x0f01,	0x0f02,	0x0f04,	0x0f08,	0x0f10,0x0f40,	//col1
	0x0781, 0x0b81, 0x0d81, 0x0e81, 0x0f82,					//row1 
	0x0784, 0x0b84, 0x0d84, 0x0e84, 0x0f84,					//row 5
	0x0781,	0x0782,	0x0784,	0x0788,	0x0790,	0x07c0, // col5
	//letter A
	0x0f01,	0x0f02,	0x0f04,	0x0f08,	0x0f10,0x0f40,	//col1
	0x0781, 0x0b81, 0x0d81, 0x0e81, 0x0f82,					//row1 
	0x0784, 0x0b84, 0x0d84, 0x0e84, 0x0f84,					//row 5
	0x0781,	0x0782,	0x0784,	0x0788,	0x0790,	0x07c0, // col5
	//letter A
	0x0f01,	0x0f02,	0x0f04,	0x0f08,	0x0f10,0x0f40,	//col1
	0x0781, 0x0b81, 0x0d81, 0x0e81, 0x0f82,					//row1 
	0x0784, 0x0b84, 0x0d84, 0x0e84, 0x0f84,					//row 5
	0x0781,	0x0782,	0x0784,	0x0788,	0x0790,	0x07c0, // col5
	//letter A
	0x0f01,	0x0f02,	0x0f04,	0x0f08,	0x0f10,0x0f40,	//col1
	0x0781, 0x0b81, 0x0d81, 0x0e81, 0x0f82,					//row1 
	0x0784, 0x0b84, 0x0d84, 0x0e84, 0x0f84,					//row 5
	0x0781,	0x0782,	0x0784,	0x0788,	0x0790,	0x07c0, // col5
	//letter A
	0x0f01,	0x0f02,	0x0f04,	0x0f08,	0x0f10,0x0f40,	//col1
	0x0781, 0x0b81, 0x0d81, 0x0e81, 0x0f82,					//row1 
	0x0784, 0x0b84, 0x0d84, 0x0e84, 0x0f84,					//row 5
	0x0781,	0x0782,	0x0784,	0x0788,	0x0790,	0x07c0, // col5
		
//letter A
	0x0f01,	0x0f02,	0x0f04,	0x0f08,	0x0f10,0x0f40,	//col1
	0x0781, 0x0b81, 0x0d81, 0x0e81, 0x0f82,					//row1 
	0x0784, 0x0b84, 0x0d84, 0x0e84, 0x0f84,					//row 5
	0x0781,	0x0782,	0x0784,	0x0788,	0x0790,	0x07c0, // col5

//letter A
	0x0f01,	0x0f02,	0x0f04,	0x0f08,	0x0f10,0x0f40,	//col1
	0x0781, 0x0b81, 0x0d81, 0x0e81, 0x0f82,					//row1 
	0x0784, 0x0b84, 0x0d84, 0x0e84, 0x0f84,					//row 5
	0x0781,	0x0782,	0x0784,	0x0788,	0x0790,	0x07c0, // col5

//letter A
	0x0f01,	0x0f02,	0x0f04,	0x0f08,	0x0f10,0x0f40,	//col1
	0x0781, 0x0b81, 0x0d81, 0x0e81, 0x0f82,					//row1 
	0x0784, 0x0b84, 0x0d84, 0x0e84, 0x0f84,					//row 5
	0x0781,	0x0782,	0x0784,	0x0788,	0x0790,	0x07c0, // col5

//letter A
	0x0f01,	0x0f02,	0x0f04,	0x0f08,	0x0f10,0x0f40,	//col1
	0x0781, 0x0b81, 0x0d81, 0x0e81, 0x0f82,					//row1 
	0x0784, 0x0b84, 0x0d84, 0x0e84, 0x0f84,					//row 5
	0x0781,	0x0782,	0x0784,	0x0788,	0x0790,	0x07c0, // col5

//letter A
	0x0f01,	0x0f02,	0x0f04,	0x0f08,	0x0f10,0x0f40,	//col1
	0x0781, 0x0b81, 0x0d81, 0x0e81, 0x0f82,					//row1 
	0x0784, 0x0b84, 0x0d84, 0x0e84, 0x0f84,					//row 5
	0x0781,	0x0782,	0x0784,	0x0788,	0x0790,	0x07c0, // col5
//letter A
	0x0f01,	0x0f02,	0x0f04,	0x0f08,	0x0f10,0x0f40,	//col1
	0x0781, 0x0b81, 0x0d81, 0x0e81, 0x0f82,					//row1 
	0x0784, 0x0b84, 0x0d84, 0x0e84, 0x0f84,					//row 5
	0x0781,	0x0782,	0x0784,	0x0788,	0x0790,	0x07c0, // col5
//letter A
	0x0f01,	0x0f02,	0x0f04,	0x0f08,	0x0f10,0x0f40,	//col1
	0x0781, 0x0b81, 0x0d81, 0x0e81, 0x0f82,					//row1 
	0x0784, 0x0b84, 0x0d84, 0x0e84, 0x0f84,					//row 5
	0x0781,	0x0782,	0x0784,	0x0788,	0x0790,	0x07c0, // col5
//letter A
	0x0f01,	0x0f02,	0x0f04,	0x0f08,	0x0f10,0x0f40,	//col1
	0x0781, 0x0b81, 0x0d81, 0x0e81, 0x0f82,					//row1 
	0x0784, 0x0b84, 0x0d84, 0x0e84, 0x0f84,					//row 5
	0x0781,	0x0782,	0x0784,	0x0788,	0x0790,	0x07c0, // col5
//letter A
	0x0f01,	0x0f02,	0x0f04,	0x0f08,	0x0f10,0x0f40,	//col1
	0x0781, 0x0b81, 0x0d81, 0x0e81, 0x0f82,					//row1 
	0x0784, 0x0b84, 0x0d84, 0x0e84, 0x0f84,					//row 5
	0x0781,	0x0782,	0x0784,	0x0788,	0x0790,	0x07c0, // col5
//letter A
	0x0f01,	0x0f02,	0x0f04,	0x0f08,	0x0f10,0x0f40,	//col1
	0x0781, 0x0b81, 0x0d81, 0x0e81, 0x0f82,					//row1 
	0x0784, 0x0b84, 0x0d84, 0x0e84, 0x0f84,					//row 5
	0x0781,	0x0782,	0x0784,	0x0788,	0x0790,	0x07c0, // col5
//letter A
	0x0f01,	0x0f02,	0x0f04,	0x0f08,	0x0f10,0x0f40,	//col1
	0x0781, 0x0b81, 0x0d81, 0x0e81, 0x0f82,					//row1 
	0x0784, 0x0b84, 0x0d84, 0x0e84, 0x0f84,					//row 5
	0x0781,	0x0782,	0x0784,	0x0788,	0x0790,	0x07c0, // col5
//letter A
	0x0f01,	0x0f02,	0x0f04,	0x0f08,	0x0f10,0x0f40,	//col1
	0x0781, 0x0b81, 0x0d81, 0x0e81, 0x0f82,					//row1 
	0x0784, 0x0b84, 0x0d84, 0x0e84, 0x0f84,					//row 5
	0x0781,	0x0782,	0x0784,	0x0788,	0x0790,	0x07c0, // col5
//letter A
	0x0f01,	0x0f02,	0x0f04,	0x0f08,	0x0f10,0x0f40,	//col1
	0x0781, 0x0b81, 0x0d81, 0x0e81, 0x0f82,					//row1 
	0x0784, 0x0b84, 0x0d84, 0x0e84, 0x0f84,					//row 5
	0x0781,	0x0782,	0x0784,	0x0788,	0x0790,	0x07c0, // col5
//letter A
	0x0f01,	0x0f02,	0x0f04,	0x0f08,	0x0f10,0x0f40,	//col1
	0x0781, 0x0b81, 0x0d81, 0x0e81, 0x0f82,					//row1 
	0x0784, 0x0b84, 0x0d84, 0x0e84, 0x0f84,					//row 5
	0x0781,	0x0782,	0x0784,	0x0788,	0x0790,	0x07c0, // col5
//letter A
	0x0f01,	0x0f02,	0x0f04,	0x0f08,	0x0f10,0x0f40,	//col1
	0x0781, 0x0b81, 0x0d81, 0x0e81, 0x0f82,					//row1 
	0x0784, 0x0b84, 0x0d84, 0x0e84, 0x0f84,					//row 5
	0x0781,	0x0782,	0x0784,	0x0788,	0x0790,	0x07c0, // col5
//letter A
	0x0f01,	0x0f02,	0x0f04,	0x0f08,	0x0f10,0x0f40,	//col1
	0x0781, 0x0b81, 0x0d81, 0x0e81, 0x0f82,					//row1 
	0x0784, 0x0b84, 0x0d84, 0x0e84, 0x0f84,					//row 5
	0x0781,	0x0782,	0x0784,	0x0788,	0x0790,	0x07c0, // col5
//letter A
	0x0f01,	0x0f02,	0x0f04,	0x0f08,	0x0f10,0x0f40,	//col1
	0x0781, 0x0b81, 0x0d81, 0x0e81, 0x0f82,					//row1 
	0x0784, 0x0b84, 0x0d84, 0x0e84, 0x0f84,					//row 5
	0x0781,	0x0782,	0x0784,	0x0788,	0x0790,	0x07c0, // col5
//letter A
	0x0f01,	0x0f02,	0x0f04,	0x0f08,	0x0f10,0x0f40,	//col1
	0x0781, 0x0b81, 0x0d81, 0x0e81, 0x0f82,					//row1 
	0x0784, 0x0b84, 0x0d84, 0x0e84, 0x0f84,					//row 5
	0x0781,	0x0782,	0x0784,	0x0788,	0x0790,	0x07c0, // col5
//letter A
	0x0f01,	0x0f02,	0x0f04,	0x0f08,	0x0f10,0x0f40,	//col1
	0x0781, 0x0b81, 0x0d81, 0x0e81, 0x0f82,					//row1 
	0x0784, 0x0b84, 0x0d84, 0x0e84, 0x0f84,					//row 5
	0x0781,	0x0782,	0x0784,	0x0788,	0x0790,	0x07c0, // col5
//letter A
	0x0f01,	0x0f02,	0x0f04,	0x0f08,	0x0f10,0x0f40,	//col1
	0x0781, 0x0b81, 0x0d81, 0x0e81, 0x0f82,					//row1 
	0x0784, 0x0b84, 0x0d84, 0x0e84, 0x0f84,					//row 5
	0x0781,	0x0782,	0x0784,	0x0788,	0x0790,	0x07c0, // col5

//letter A
	0x0f01,	0x0f02,	0x0f04,	0x0f08,	0x0f10,0x0f40,	//col1
	0x0781, 0x0b81, 0x0d81, 0x0e81, 0x0f82,					//row1 
	0x0784, 0x0b84, 0x0d84, 0x0e84, 0x0f84,					//row 5
	0x0781,	0x0782,	0x0784,	0x0788,	0x0790,	0x07c0, // col5

//letter A
	0x0f01,	0x0f02,	0x0f04,	0x0f08,	0x0f10,0x0f40,	//col1
	0x0781, 0x0b81, 0x0d81, 0x0e81, 0x0f82,					//row1 
	0x0784, 0x0b84, 0x0d84, 0x0e84, 0x0f84,					//row 5
	0x0781,	0x0782,	0x0784,	0x0788,	0x0790,	0x07c0, // col5

//letter A
	0x0f01,	0x0f02,	0x0f04,	0x0f08,	0x0f10,0x0f40,	//col1
	0x0781, 0x0b81, 0x0d81, 0x0e81, 0x0f82,					//row1 
	0x0784, 0x0b84, 0x0d84, 0x0e84, 0x0f84,					//row 5
	0x0781,	0x0782,	0x0784,	0x0788,	0x0790,	0x07c0, // col5

//letter A
	0x0f01,	0x0f02,	0x0f04,	0x0f08,	0x0f10,0x0f40,	//col1
	0x0781, 0x0b81, 0x0d81, 0x0e81, 0x0f82,					//row1 
	0x0784, 0x0b84, 0x0d84, 0x0e84, 0x0f84,					//row 5
	0x0781,	0x0782,	0x0784,	0x0788,	0x0790,	0x07c0, // col5

//letter A
	0x0f01,	0x0f02,	0x0f04,	0x0f08,	0x0f10,0x0f40,	//col1
	0x0781, 0x0b81, 0x0d81, 0x0e81, 0x0f82,					//row1 
	0x0784, 0x0b84, 0x0d84, 0x0e84, 0x0f84,					//row 5
	0x0781,	0x0782,	0x0784,	0x0788,	0x0790,	0x07c0, // col5

//letter A
	0x0f01,	0x0f02,	0x0f04,	0x0f08,	0x0f10,0x0f40,	//col1
	0x0781, 0x0b81, 0x0d81, 0x0e81, 0x0f82,					//row1 
	0x0784, 0x0b84, 0x0d84, 0x0e84, 0x0f84,					//row 5
	0x0781,	0x0782,	0x0784,	0x0788,	0x0790,	0x07c0, // col5

//letter A
	0x0f01,	0x0f02,	0x0f04,	0x0f08,	0x0f10,0x0f40,	//col1
	0x0781, 0x0b81, 0x0d81, 0x0e81, 0x0f82,					//row1 
	0x0784, 0x0b84, 0x0d84, 0x0e84, 0x0f84,					//row 5
	0x0781,	0x0782,	0x0784,	0x0788,	0x0790,	0x07c0, // col5

//letter A
	0x0f01,	0x0f02,	0x0f04,	0x0f08,	0x0f10,0x0f40,	//col1
	0x0781, 0x0b81, 0x0d81, 0x0e81, 0x0f82,					//row1 
	0x0784, 0x0b84, 0x0d84, 0x0e84, 0x0f84,					//row 5
	0x0781,	0x0782,	0x0784,	0x0788,	0x0790,	0x07c0, // col5

//letter A
	0x0f01,	0x0f02,	0x0f04,	0x0f08,	0x0f10,0x0f40,	//col1
	0x0781, 0x0b81, 0x0d81, 0x0e81, 0x0f82,					//row1 
	0x0784, 0x0b84, 0x0d84, 0x0e84, 0x0f84,					//row 5
	0x0781,	0x0782,	0x0784,	0x0788,	0x0790,	0x07c0, // col5

//letter A
	0x0f01,	0x0f02,	0x0f04,	0x0f08,	0x0f10,0x0f40,	//col1
	0x0781, 0x0b81, 0x0d81, 0x0e81, 0x0f82,					//row1 
	0x0784, 0x0b84, 0x0d84, 0x0e84, 0x0f84,					//row 5
	0x0781,	0x0782,	0x0784,	0x0788,	0x0790,	0x07c0, // col5

//letter A
	0x0f01,	0x0f02,	0x0f04,	0x0f08,	0x0f10,0x0f40,	//col1
	0x0781, 0x0b81, 0x0d81, 0x0e81, 0x0f82,					//row1 
	0x0784, 0x0b84, 0x0d84, 0x0e84, 0x0f84,					//row 5
	0x0781,	0x0782,	0x0784,	0x0788,	0x0790,	0x07c0 // col5



};

int i=0;
void delay(void) {
		// Insert some delay
		i = 1024*1024;
 		while(i--);
	
	
}	
int main(void)
{
		AD1PCFG = 0xFFFFFFFF; //added for EXP 32
    	DDPCON=0x00; //added fOR EXP 32 to turn off JTAG
   
	int	dmaChn=0;		// the DMA channel to use
	mPORTBClearBits(BIT_12 | BIT_11 );
	mPORTBSetBits(BIT_11 );
	mPORTBSetPinsDigitalOut( BIT_12 | BIT_11 );

	// first let us set the LED I/O ports as digital outputs
//	mPORTDSetPinsDigitalOut(0xff);
//	mPORTDClearBits(0xff);		// start with all LED's turned off
	mPORTDSetBits(BIT_11 | BIT_10 | BIT_9 | BIT_8 |BIT_7  ); // turn off columns
mPORTDClearBits( BIT_6 |BIT_5 | BIT_4 | BIT_3 | BIT_2 |BIT_1 | BIT_0 ); //clear rows
mPORTDSetPinsDigitalOut(BIT_11 | BIT_10 | BIT_9 | BIT_8 |BIT_7 | BIT_6 |BIT_5 | BIT_4 | BIT_3 | BIT_2 |BIT_1 | BIT_0 );

	// Open the desired DMA channel.
	// We enable the AUTO option, we'll keep repeating the sam transfer over and over.
	DmaChnOpen(dmaChn, 0, DMA_OPEN_AUTO);

	// set the transfer parameters: source & destination address, source & destination size, number of bytes per event
	DmaChnSetTxfer(dmaChn, LED_pattern, (void*)&LATD, sizeof(LED_pattern), 2, 2); //desination =2 and tranfer =2

	// set the transfer event control: what event is to start the DMA transfer
	DmaChnSetEventControl(dmaChn, DMA_EV_START_IRQ(_TIMER_3_IRQ));

	// once we configured the DMA channel we can enable it
	// now it's ready and waiting for an event to occur...
	DmaChnEnable(dmaChn);


	// now use the 32 bit timer to generate an interrupt at the desired LED_BLINK_RATE
	{
		int	pbFreq=SYS_FREQ/(1<<mOSCGetPBDIV());	// get the PB frequency the timer is running at

		// use 1:1 prescaler for max resolution, the PB clock
		OpenTimer23(T2_ON | T2_SOURCE_INT | T2_PS_1_1, (pbFreq/1000/4)*LED_BLINK_RATE);
	}


	while(1)
	{
		// do some other useful work
			mPORTBToggleBits(BIT_12 | BIT_11  );
			delay();
	}


}





