/*
    FreeRTOS V6.0.0 - Copyright (C) 2009 Real Time Engineers Ltd.

    This file is part of the FreeRTOS distribution.

    FreeRTOS is free software; you can redistribute it and/or modify it under
    the terms of the GNU General Public License (version 2) as published by the
    Free Software Foundation AND MODIFIED BY the FreeRTOS exception.
    ***NOTE*** The exception to the GPL is included to allow you to distribute
    a combined work that includes FreeRTOS without being obliged to provide the
    source code for proprietary components outside of the FreeRTOS kernel.
    FreeRTOS is distributed in the hope that it will be useful, but WITHOUT
    ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
    FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License for
    more details. You should have received a copy of the GNU General Public 
    License and the FreeRTOS license exception along with FreeRTOS; if not it 
    can be viewed here: http://www.freertos.org/a00114.html and also obtained 
    by writing to Richard Barry, contact details for whom are available on the
    FreeRTOS WEB site.

    1 tab == 4 spaces!

    http://www.FreeRTOS.org - Documentation, latest information, license and
    contact details.

    http://www.SafeRTOS.com - A version that is certified for use in safety
    critical systems.

    http://www.OpenRTOS.com - Commercial support, development, porting,
    licensing and training services.
    modified by thk 4/18/10 for CN on PORTD bit 0 and toggle LED bit2
    modified by thk 12/11/10 for exp32 for setup environment
    	set analog ports to digital and turn off jtag
    	activate portB SW1 RB15/CN12
    	activate portD 8 PINS
    	
    modify for use 12/16/10  with LED MATRIX
*/

/* MPLAB includes. */
#include <p32xxxx.h>
#include <plib.h>

/* FreeRTOS.org includes. */
#include "FreeRTOS.h"
#include "task.h"
#include "semphr.h"

/* Demo includes. */
#include "basic_io.h"

/* PIC32 configuration. */
#pragma config FPLLODIV = DIV_1, FPLLMUL = MUL_20, FPLLIDIV = DIV_2
#pragma config FWDTEN = OFF, FPBDIV = DIV_2, POSCMOD = XT, FNOSC = PRIPLL, CP = OFF
#pragma config FSRSSEL = PRIORITY_7


#define CONFIG          (CN_ON | CN_IDLE_CON)
#define PINS            (CN12_ENABLE)
#define PULLUPS         (CN12_PULLUP_ENABLE)
#define INTERRUPT       (CHANGE_INT_ON | CHANGE_INT_PRI_2)

//led matrix assignments
//LEDXY   X =COL  Y =ROW

#define LED11  0x0f01
#define LED12  0x0f02
#define LED13  0x0f04
#define LED14  0x0f08
#define LED15  0x0f10
#define LED16  0x0f40
#define LED17  0x0e81

/* The tasks to be created. */
static void vHandlerTask( void *pvParameters );
void vTask1( void *pvParameters );
void vTask2( void *pvParameters );
void vTask3( void *pvParameters );
void vTask4( void *pvParameters );
void vTask5( void *pvParameters );
void vTask6( void *pvParameters );
void vTask7( void *pvParameters );
static void prvToggleLED( unsigned portBASE_TYPE uxLED );
/* The service routine for the interrupt.  This is the interrupt that the 
task will be synchronized with.  The C compiler extensions are used to 
indicate that this is an interrupt entry point to use for the 
_CORE_SOFTWARE_1_VECTOR vector location.  The assembly wrapper for the 
interrupt (vSW1_ISR_Wrapper()) is defined in ISR_Wrapper.S, the C portion of
the handler (vSW1_ISR_Handler()) is defined in this file. */

void __attribute__( (interrupt(ipl2), vector(_CHANGE_NOTICE_VECTOR))) vSW1_ISR_Wrapper( void );


/* Basic hardware and debug interface configuration. */
void vSetupEnvironment( void );

/*-----------------------------------------------------------*/

/* Declare a variable of type xSemaphoreHandle.  This is used to reference the
semaphore that is used to synchronize a task with an interrupt. */
xSemaphoreHandle xBinarySemaphore;

/*-----------------------------------------------------------*/
volatile unsigned int temp;
volatile unsigned int myflag =0;
volatile unsigned int mycount =0;
xTaskHandle xTask1Handle,  xTask2Handle,xTask3Handle,xTask4Handle;  // taskhandles
xTaskHandle xTask5Handle, xTask6Handle, xTask7Handle;
int main( void )
{
    /* Configure both the hardware and the debug interface. */
    vSetupEnvironment();

 int image = LED11; //image is col row setting for col 1 row 1 LED
   	xTaskCreate( vTask1,"Task 1",240,(void*)image,1,&xTask1Handle ); 
	image = LED12;
	xTaskCreate( vTask2, "Task 2", 240,(void*)image, 1, &xTask2Handle );
	image = LED13;
	xTaskCreate( vTask3, "Task 3", 240, (void*)image, 1, &xTask3Handle );
	image = LED14;
	xTaskCreate( vTask4, "Task 4", 240, (void*)image, 1, &xTask4Handle );
	image = LED15;
	xTaskCreate( vTask5, "Task 5", 240, (void*)image, 1, &xTask5Handle );
	image = LED16;
	xTaskCreate( vTask6, "Task 6", 240, (void*)image, 1, &xTask6Handle );
	image = LED17;
	xTaskCreate( vTask7, "Task 7", 240, (void*)image, 1, &xTask7Handle );
    /* Before a semaphore is used it must be explicitly created.  In this example
    a binary semaphore is created. */
    vSemaphoreCreateBinary( xBinarySemaphore );

    /* Check the semaphore was created successfully. */
    if( xBinarySemaphore != NULL )
    {
        /* Create the 'handler' task.  This is the task that will be synchronized
        with the interrupt.  The handler task is created with a high priority to
        ensure it runs immediately after the interrupt exits.  In this case a 
        priority of 3 is chosen. */
        xTaskCreate( vHandlerTask, "Handler", 240, NULL, 3, NULL );

       

        /* Start the scheduler so the created tasks start executing. */
        vTaskStartScheduler();
    }
        
    /* If all is well we will never reach here as the scheduler will now be
    running the tasks.  If we do reach here then it is likely that there was 
    insufficient heap memory available for a resource to be created. */
    for( ;; );
    return 0;
}
/*-----------------------------------------------------------*/

static void vHandlerTask( void *pvParameters )
{
    /* As per most tasks, this task is implemented within an infinite loop.
    
    Take the semaphore once to start with so the semaphore is empty before the
    infinite loop is entered.  The semaphore was created before the scheduler 
    was started so before this task ran for the first time.*/
   myflag=0;
   mycount =0;
    xSemaphoreTake( xBinarySemaphore, 0 );
    
    for( ;; )
    {
        /* Use the semaphore to wait for the event.  The task blocks 
        indefinitely meaning this function call will only return once the 
        semaphore has been successfully obtained - so there is no need to check
        the returned value. */
        xSemaphoreTake( xBinarySemaphore, portMAX_DELAY );
        myflag++;
        if (myflag==2) {
	        myflag =0;
	        mycount++;
	         switch (mycount) 
	       {
		      case 1:
		      vTaskSuspend( xTask1Handle);
		      break;
		      case 2:
		       vTaskSuspend( xTask2Handle);
		      break;
		      case 3:
		       vTaskSuspend( xTask3Handle);
		      break;
		      case 4:
		       vTaskSuspend( xTask4Handle);
		      break;
		      case 5:
		       vTaskSuspend( xTask5Handle);
		      break;
		      case 6:
		       vTaskSuspend( xTask6Handle);
		      break;
		      case 7:
		       vTaskSuspend( xTask7Handle);
		      break;
		      case 8:
		      vTaskResume( xTask1Handle);
		      break;
		      case 9:
		        vTaskResume( xTask2Handle);
		      break;
		      case 10:
		        vTaskResume( xTask3Handle);
		      break;
		      case 11:
		        vTaskResume( xTask4Handle);
		      break;
		      case 12:
		        vTaskResume( xTask5Handle);
		      break;
		       case 13:
		        vTaskResume( xTask6Handle);
		      break;
		       case 14:
		        vTaskResume( xTask7Handle);
		        mycount=0;
		      break;
		      
		      default:
		      break;
		   
		      }  
	        
	       }
	      

        /* To get here the event must have occurred.  Process the event (in this
        case we just print out a message). */
      //  vPrintString( "Handler task - Processing event.\n" );
    }
}
/*-----------------------------------------------------------*/

/*-----------------------------------------------------------*/

void vSW1_ISR_Handler( void )
{
portBASE_TYPE xHigherPriorityTaskWoken = pdFALSE;

    /* 'Give' the semaphore to unblock the task. */
    xSemaphoreGiveFromISR( xBinarySemaphore, &xHigherPriorityTaskWoken );

    /* Clear the software interrupt flag. */
    //mainCLEAR_INTERRUPT();
    unsigned int temp;

    // clear the mismatch condition
    temp = mPORTBRead(); //clear portb sw1

    // clear the interrupt flag
    mCNClearIntFlag();

    // .. things to do .. toggle the led
    mPORTBToggleBits(BIT_12); //toggle L1

    
    /* Giving the semaphore may have unblocked a task - if it did and the 
    unblocked task has a priority equal to or above the currently executing 
    task then xHigherPriorityTaskWoken will have been set to pdTRUE and
    portEND_SWITCHING_ISR() will force a context switch to the newly unblocked
    higher priority task.
    
    NOTE: The syntax for forcing a context switch within an ISR varies between 
    FreeRTOS ports.  The portEND_SWITCHING_ISR() macro is provided as part of
    the PIC32 port layer for this purpose.  taskYIELD() must never be called 
    from an ISR! */
    portEND_SWITCHING_ISR( xHigherPriorityTaskWoken );
}
/*-----------------------------------------------------------*/

void vSetupEnvironment( void )
{
    /* Setup the main clock for maximum performance, and the peripheral clock
    to equal the main clock divided by 2. */
    SYSTEMConfigPerformance( configCPU_CLOCK_HZ );
    mOSCSetPBDIV( OSC_PB_DIV_2 );
    	AD1PCFG = 0xFFFFFFFF; //added for EXP 32
    	DDPCON=0x00; //added fOR EXP 32 to turn off JTAG
   
     //~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
    // STEP 2. configure the port registers

 mPORTBClearBits(BIT_12 | BIT_11 );
mPORTBSetPinsDigitalOut( BIT_12 | BIT_11 ); //LED1, LED2


mPORTDSetPinsDigitalOut(BIT_11 | BIT_10 | BIT_9 | BIT_8 |BIT_7 | BIT_6 | BIT_4 | BIT_3 | BIT_2 |BIT_1 | BIT_0 );

    PORTSetPinsDigitalIn(IOPORT_B, BIT_15);  //SW1

    //~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
    // STEP 3. initialize the port pin states = turn off columns , clear rows
mPORTDSetBits(BIT_11 | BIT_10 | BIT_9 | BIT_8 |BIT_7  ); // turn off columns

mPORTDClearBits( BIT_6 | BIT_4 | BIT_3 | BIT_2 |BIT_1 | BIT_0 ); //clear rows
    // Note: It is recommended to disable vector interrupts prior to
    // configuring the change notice module, if they are enabled.
    // The user must read one or more IOPORTs to clear the IO pin
    // change notice mismatch condition, then clear the change notice
    // interrupt flag before re-enabling the vector interrupts.

    //~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
    // STEP 4. enable change notice, enable discrete pins and weak pullups
    mCNOpen(CONFIG, PINS, PULLUPS);

    //~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
    // STEP 5. read port(s) to clear mismatch on change notice pins
    temp = mPORTBRead();

    //~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
    // STEP 6. clear change notice interrupt flag
    ConfigIntCN(INTERRUPT);

    /* Enable global interrupt handling. */
    INTEnableSystemMultiVectoredInt();

    /* Initialise the debug utils library to enable strings printed from the
    demo source code to be displayed in the MPLAB IDE. */
   // DBINIT();
}
/*-----------------------------------------------------------*/
void prvToggleLED( unsigned portBASE_TYPE uxLED )
{
unsigned portBASE_TYPE uxLEDBit;
	
	uxLEDBit = 1 << uxLED;

	/* Use of the PORTDINV register removes the need to use a critical section. */
	PORTDINV = uxLEDBit;
}
void vTask1( void *pvParameters )
{
	unsigned portBASE_TYPE imagex = ( unsigned portBASE_TYPE ) pvParameters;
//volatile unsigned portLONG ul;

int i;

const char *pcTaskName = "Task 1 is running\n";
volatile unsigned long ul;

	/* As per most tasks, this task is implemented in an infinite loop. */
	for( ;; )
	{
		/* Print out the name of this task. */
	//		vPrintString( pcTaskName );
		taskENTER_CRITICAL();
	
	LATD =imagex;
	

	i = 512*512;
		while(i--);

	taskEXIT_CRITICAL();
		vTaskDelay(250/portTICK_RATE_MS);
		/* Delay for a period. */

	}
}
/*-----------------------------------------------------------*/

void vTask2( void *pvParameters )
{
	unsigned portBASE_TYPE imagex = ( unsigned portBASE_TYPE ) pvParameters;
//volatile unsigned portLONG ul;
int i;

const char *pcTaskName = "Task 2 is running\n";
volatile unsigned long ul;

	/* As per most tasks, this task is implemented in an infinite loop. */
	for( ;; )
	{
		/* Print out the name of this task. */
	
	taskENTER_CRITICAL();
PORTD =imagex;

	i = 512*512;
		while(i--);
			taskEXIT_CRITICAL();
	vTaskDelay(250/portTICK_RATE_MS);
		/* Delay for a period. */

	}
}
/*-----------------------------------------------------------*/

/*-----------------------------------------------------------*/

void vTask3( void *pvParameters )
{
	unsigned portBASE_TYPE imagex = ( unsigned portBASE_TYPE ) pvParameters;
//volatile unsigned portLONG ul;
int i;
const char *pcTaskName = "Task 3 is running\n";
volatile unsigned long ul;

	/* As per most tasks, this task is implemented in an infinite loop. */
	for( ;; )
	{
		taskENTER_CRITICAL();
PORTD =imagex;

	i = 512*512;
		while(i--);
			taskEXIT_CRITICAL();
	vTaskDelay(250/portTICK_RATE_MS);
		/* Delay for a period. */	
	
	}
}
/*-----------------------------------------------------------*/

/*-----------------------------------------------------------*/

void vTask4( void *pvParameters )
{
	unsigned portBASE_TYPE imagex = ( unsigned portBASE_TYPE ) pvParameters;
//volatile unsigned portLONG ul;

const char *pcTaskName = "Task 4 is running\n";
volatile unsigned long ul;
int i;
	/* As per most tasks, this task is implemented in an infinite loop. */
	for( ;; )
	{
		taskENTER_CRITICAL();
PORTD =imagex;

	i = 512*512;
		while(i--);
			taskEXIT_CRITICAL();
	vTaskDelay(250/portTICK_RATE_MS);
		/* Delay for a period. */
	}
}
/*-----------------------------------------------------------*/
/*-----------------------------------------------------------*/

void vTask5( void *pvParameters )
{
	unsigned portBASE_TYPE imagex = ( unsigned portBASE_TYPE ) pvParameters;
//volatile unsigned portLONG ul;

const char *pcTaskName = "Task 5 is running\n";
volatile unsigned long ul;
int i;
	/* As per most tasks, this task is implemented in an infinite loop. */
	for( ;; )
	{
		taskENTER_CRITICAL();
PORTD =imagex;

	i = 512*512;
		while(i--);
			taskEXIT_CRITICAL();
	vTaskDelay(250/portTICK_RATE_MS);
		/* Delay for a period. */	
	}
}
/*-----------------------------------------------------------*/

/*-----------------------------------------------------------*/
/*-----------------------------------------------------------*/

void vTask6( void *pvParameters )
{
	unsigned portBASE_TYPE imagex = ( unsigned portBASE_TYPE ) pvParameters;
//volatile unsigned portLONG ul;
int i;

const char *pcTaskName = "Task 6 is running\n";
volatile unsigned long ul;

	/* As per most tasks, this task is implemented in an infinite loop. */
	for( ;; )
	{
			
	taskENTER_CRITICAL();
PORTD =imagex;

	i = 512*512;
		while(i--);
			taskEXIT_CRITICAL();
	vTaskDelay(250/portTICK_RATE_MS);
		/* Delay for a period. */
	}
}
/*-----------------------------------------------------------*/
/*-----------------------------------------------------------*/

void vTask7( void *pvParameters )
{
	unsigned portBASE_TYPE imagex = ( unsigned portBASE_TYPE ) pvParameters;
//volatile unsigned portLONG ul;
int i;

const char *pcTaskName = "Task 7 is running\n";
volatile unsigned long ul;

	/* As per most tasks, this task is implemented in an infinite loop. */
	for( ;; )
	{
			
	taskENTER_CRITICAL();
PORTD =imagex;

	i = 512*512;
		while(i--);
			taskEXIT_CRITICAL();
	vTaskDelay(250/portTICK_RATE_MS);
		/* Delay for a period. */
	}
}